==> jc-1.4.0.tar.gz: soot/jimple/spark/BDDSparkTransformer.h <==
// public class soot.jimple.spark.BDDSparkTransformer

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 1988ae632461b86a soot_SceneTransformer
// @dep_class de5fa3182955e270 soot_Transformer
// @dep_class 120bc7bd95b93244 soot_jimple_spark_AbstractSparkTransformer
// @dep_class ae801d124477991b soot_jimple_spark_BDDSparkTransformer

// header file dependencies
// @dep_header soot_jimple_spark_AbstractSparkTransformer

#include "soot/jimple/spark/AbstractSparkTransformer.h"

#ifndef _JC_soot_jimple_spark_BDDSparkTransformer_H_
#define _JC_soot_jimple_spark_BDDSparkTransformer_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Map$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_jimple_spark_BDDSparkTransformer$object;
struct _jc_soot_jimple_spark_builder_ContextInsensitiveBuilder$object;
struct _jc_soot_jimple_spark_pag_BDDPAG$object;

// Typedefs
typedef struct _jc_soot_jimple_spark_BDDSparkTransformer$sub_refs	_jc_soot_jimple_spark_BDDSparkTransformer$sub_refs;
typedef struct _jc_soot_jimple_spark_BDDSparkTransformer$sub_nonrefs	_jc_soot_jimple_spark_BDDSparkTransformer$sub_nonrefs;
typedef struct _jc_soot_jimple_spark_BDDSparkTransformer$refs	_jc_soot_jimple_spark_BDDSparkTransformer$refs;
typedef struct _jc_soot_jimple_spark_BDDSparkTransformer$nonrefs	_jc_soot_jimple_spark_BDDSparkTransformer$nonrefs;
typedef struct _jc_soot_jimple_spark_BDDSparkTransformer$object	_jc_soot_jimple_spark_BDDSparkTransformer$object;

typedef const struct _jc_soot_jimple_spark_BDDSparkTransformer$vmethods	_jc_soot_jimple_spark_BDDSparkTransformer$vmethods;
typedef const struct _jc_soot_jimple_spark_BDDSparkTransformer$vtable	_jc_soot_jimple_spark_BDDSparkTransformer$vtable;
typedef const struct _jc_soot_jimple_spark_BDDSparkTransformer$vtype	_jc_soot_jimple_spark_BDDSparkTransformer$vtype;

// Constructors
extern void _jc_soot_jimple_spark_BDDSparkTransformer$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_jimple_spark_BDDSparkTransformer$object *, struct _jc_soot_Singletons__24Global$object *);

// Virtual methods
extern void _jc_soot_jimple_spark_BDDSparkTransformer$method$addTags$b3786ca24283751f(_jc_env *, struct _jc_soot_jimple_spark_BDDSparkTransformer$object *, struct _jc_soot_jimple_spark_pag_BDDPAG$object *);
extern void _jc_soot_jimple_spark_BDDSparkTransformer$method$findSetMass$4a9a3c72b984ae56(_jc_env *, struct _jc_soot_jimple_spark_BDDSparkTransformer$object *, struct _jc_soot_jimple_spark_pag_BDDPAG$object *, struct _jc_soot_jimple_spark_builder_ContextInsensitiveBuilder$object *);
extern void _jc_soot_jimple_spark_BDDSparkTransformer$method$internalTransform$b44b61d0d9f22a06(_jc_env *, struct _jc_soot_jimple_spark_BDDSparkTransformer$object *, struct _jc_java_lang_String$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_spark_BDDSparkTransformer$method_info$addTags$b3786ca24283751f;
extern _jc_method _jc_soot_jimple_spark_BDDSparkTransformer$method_info$findSetMass$4a9a3c72b984ae56;
extern _jc_method _jc_soot_jimple_spark_BDDSparkTransformer$method_info$internalTransform$b44b61d0d9f22a06;

// Static methods
extern struct _jc_soot_jimple_spark_BDDSparkTransformer$object *_jc_soot_jimple_spark_BDDSparkTransformer$method$v$c784a50615a67eea(_jc_env *);

// Virtual methods structure
struct _jc_soot_jimple_spark_BDDSparkTransformer$vmethods {
	void	(*addTags$b3786ca24283751f)(_jc_env *, struct _jc_soot_jimple_spark_BDDSparkTransformer$object *, struct _jc_soot_jimple_spark_pag_BDDPAG$object *);
	void	(*findSetMass$4a9a3c72b984ae56)(_jc_env *, struct _jc_soot_jimple_spark_BDDSparkTransformer$object *, struct _jc_soot_jimple_spark_pag_BDDPAG$object *, struct _jc_soot_jimple_spark_builder_ContextInsensitiveBuilder$object *);
	void	(*internalTransform$b44b61d0d9f22a06)(_jc_env *, struct _jc_soot_jimple_spark_BDDSparkTransformer$object *, struct _jc_java_lang_String$object *, struct _jc_object *);
};

// Vtable
struct _jc_soot_jimple_spark_BDDSparkTransformer$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_Transformer$vmethods	soot_Transformer;
	_jc_soot_SceneTransformer$vmethods	soot_SceneTransformer;
	_jc_soot_jimple_spark_AbstractSparkTransformer$vmethods	soot_jimple_spark_AbstractSparkTransformer;
	_jc_soot_jimple_spark_BDDSparkTransformer$vmethods	soot_jimple_spark_BDDSparkTransformer;
};

// Vtype
struct _jc_soot_jimple_spark_BDDSparkTransformer$vtype {
	_jc_type			type;
	_jc_soot_jimple_spark_BDDSparkTransformer$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_spark_BDDSparkTransformer$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_spark_BDDSparkTransformer$refs {
    _jc_soot_jimple_spark_BDDSparkTransformer$sub_refs	soot_jimple_spark_BDDSparkTransformer;
    _jc_soot_jimple_spark_AbstractSparkTransformer$sub_refs	soot_jimple_spark_AbstractSparkTransformer;
    _jc_soot_SceneTransformer$sub_refs	soot_SceneTransformer;
    _jc_soot_Transformer$sub_refs	soot_Transformer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_spark_BDDSparkTransformer$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_spark_BDDSparkTransformer$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_Transformer$sub_nonrefs	soot_Transformer;
    _jc_soot_SceneTransformer$sub_nonrefs	soot_SceneTransformer;
    _jc_soot_jimple_spark_AbstractSparkTransformer$sub_nonrefs	soot_jimple_spark_AbstractSparkTransformer;
    _jc_soot_jimple_spark_BDDSparkTransformer$sub_nonrefs	soot_jimple_spark_BDDSparkTransformer;
};

// Object instance structure
struct _jc_soot_jimple_spark_BDDSparkTransformer$object {
	_jc_soot_jimple_spark_BDDSparkTransformer$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_spark_BDDSparkTransformer$vtype	*vtype;
	_jc_soot_jimple_spark_BDDSparkTransformer$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_spark_BDDSparkTransformer$vtype _jc_soot_jimple_spark_BDDSparkTransformer$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_spark_BDDSparkTransformer, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_spark_BDDSparkTransformer$class_object;

#endif	/* _JC_soot_jimple_spark_BDDSparkTransformer_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/spark/BDDSparkTransformer.h <==
// public class soot.jimple.spark.BDDSparkTransformer

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 1988ae632461b86a soot_SceneTransformer
// @dep_class de5fa3182955e270 soot_Transformer
// @dep_class 120bc7bd95b93244 soot_jimple_spark_AbstractSparkTransformer
// @dep_class ae801d124477991b soot_jimple_spark_BDDSparkTransformer

// header file dependencies
// @dep_header soot_jimple_spark_AbstractSparkTransformer

#include "soot/jimple/spark/AbstractSparkTransformer.h"

#ifndef _JC_soot_jimple_spark_BDDSparkTransformer_H_
#define _JC_soot_jimple_spark_BDDSparkTransformer_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Map$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_jimple_spark_BDDSparkTransformer$object;
struct _jc_soot_jimple_spark_builder_ContextInsensitiveBuilder$object;
struct _jc_soot_jimple_spark_pag_BDDPAG$object;

// Typedefs
typedef struct _jc_soot_jimple_spark_BDDSparkTransformer$sub_refs	_jc_soot_jimple_spark_BDDSparkTransformer$sub_refs;
typedef struct _jc_soot_jimple_spark_BDDSparkTransformer$sub_nonrefs	_jc_soot_jimple_spark_BDDSparkTransformer$sub_nonrefs;
typedef struct _jc_soot_jimple_spark_BDDSparkTransformer$refs	_jc_soot_jimple_spark_BDDSparkTransformer$refs;
typedef struct _jc_soot_jimple_spark_BDDSparkTransformer$nonrefs	_jc_soot_jimple_spark_BDDSparkTransformer$nonrefs;
typedef struct _jc_soot_jimple_spark_BDDSparkTransformer$object	_jc_soot_jimple_spark_BDDSparkTransformer$object;

typedef const struct _jc_soot_jimple_spark_BDDSparkTransformer$vmethods	_jc_soot_jimple_spark_BDDSparkTransformer$vmethods;
typedef const struct _jc_soot_jimple_spark_BDDSparkTransformer$vtable	_jc_soot_jimple_spark_BDDSparkTransformer$vtable;
typedef const struct _jc_soot_jimple_spark_BDDSparkTransformer$vtype	_jc_soot_jimple_spark_BDDSparkTransformer$vtype;

// Constructors
extern void _jc_soot_jimple_spark_BDDSparkTransformer$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_jimple_spark_BDDSparkTransformer$object *, struct _jc_soot_Singletons__24Global$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_spark_BDDSparkTransformer$method$addTags$b3786ca24283751f(_jc_env *, struct _jc_soot_jimple_spark_BDDSparkTransformer$object *, struct _jc_soot_jimple_spark_pag_BDDPAG$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_spark_BDDSparkTransformer$method$findSetMass$4a9a3c72b984ae56(_jc_env *, struct _jc_soot_jimple_spark_BDDSparkTransformer$object *, struct _jc_soot_jimple_spark_pag_BDDPAG$object *, struct _jc_soot_jimple_spark_builder_ContextInsensitiveBuilder$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_spark_BDDSparkTransformer$method$internalTransform$b44b61d0d9f22a06(_jc_env *, struct _jc_soot_jimple_spark_BDDSparkTransformer$object *, struct _jc_java_lang_String$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_spark_BDDSparkTransformer$method_info$addTags$b3786ca24283751f;
extern _jc_method _jc_soot_jimple_spark_BDDSparkTransformer$method_info$findSetMass$4a9a3c72b984ae56;
extern _jc_method _jc_soot_jimple_spark_BDDSparkTransformer$method_info$internalTransform$b44b61d0d9f22a06;

// Static methods
extern struct _jc_soot_jimple_spark_BDDSparkTransformer$object *_jc_soot_jimple_spark_BDDSparkTransformer$method$v$c784a50615a67eea(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_jimple_spark_BDDSparkTransformer$vmethods {
	void	(*addTags$b3786ca24283751f)(_jc_env *, struct _jc_soot_jimple_spark_BDDSparkTransformer$object *, struct _jc_soot_jimple_spark_pag_BDDPAG$object *) _JC_JCNI_ATTR;
	void	(*findSetMass$4a9a3c72b984ae56)(_jc_env *, struct _jc_soot_jimple_spark_BDDSparkTransformer$object *, struct _jc_soot_jimple_spark_pag_BDDPAG$object *, struct _jc_soot_jimple_spark_builder_ContextInsensitiveBuilder$object *) _JC_JCNI_ATTR;
	void	(*internalTransform$b44b61d0d9f22a06)(_jc_env *, struct _jc_soot_jimple_spark_BDDSparkTransformer$object *, struct _jc_java_lang_String$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_spark_BDDSparkTransformer$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_Transformer$vmethods	soot_Transformer;
	_jc_soot_SceneTransformer$vmethods	soot_SceneTransformer;
	_jc_soot_jimple_spark_AbstractSparkTransformer$vmethods	soot_jimple_spark_AbstractSparkTransformer;
	_jc_soot_jimple_spark_BDDSparkTransformer$vmethods	soot_jimple_spark_BDDSparkTransformer;
};

// Vtype
struct _jc_soot_jimple_spark_BDDSparkTransformer$vtype {
	_jc_type			type;
	_jc_soot_jimple_spark_BDDSparkTransformer$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_spark_BDDSparkTransformer$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_spark_BDDSparkTransformer$refs {
    _jc_soot_jimple_spark_BDDSparkTransformer$sub_refs	soot_jimple_spark_BDDSparkTransformer;
    _jc_soot_jimple_spark_AbstractSparkTransformer$sub_refs	soot_jimple_spark_AbstractSparkTransformer;
    _jc_soot_SceneTransformer$sub_refs	soot_SceneTransformer;
    _jc_soot_Transformer$sub_refs	soot_Transformer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_spark_BDDSparkTransformer$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_spark_BDDSparkTransformer$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_Transformer$sub_nonrefs	soot_Transformer;
    _jc_soot_SceneTransformer$sub_nonrefs	soot_SceneTransformer;
    _jc_soot_jimple_spark_AbstractSparkTransformer$sub_nonrefs	soot_jimple_spark_AbstractSparkTransformer;
    _jc_soot_jimple_spark_BDDSparkTransformer$sub_nonrefs	soot_jimple_spark_BDDSparkTransformer;
};

// Object instance structure
struct _jc_soot_jimple_spark_BDDSparkTransformer$object {
	_jc_soot_jimple_spark_BDDSparkTransformer$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_spark_BDDSparkTransformer$vtype	*vtype;
	_jc_soot_jimple_spark_BDDSparkTransformer$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_spark_BDDSparkTransformer$vtype _jc_soot_jimple_spark_BDDSparkTransformer$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_spark_BDDSparkTransformer, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_spark_BDDSparkTransformer$class_object;

#endif	/* _JC_soot_jimple_spark_BDDSparkTransformer_H_ */
